# 🤖 tgpirobot - Telegram Auto Reply Bot

<p align="center">
  <img src="https://user-images.githubusercontent.com/5070591/115477479-2a8d2f00-a28a-11eb-85e7-aedbf1a9f829.png">
</p>

<p align="center">
  <a href="https://github.com/hk4crprasad/tgpirobot">
    <img src="https://img.shields.io/github/stars/hk4crprasad/tgpirobot?style=for-the-badge&color=ee6712"> 
  </a>
  <a href="https://pypi.org/project/tgpirobot">
    <img src="https://img.shields.io/pypi/v/tgpirobot?style=for-the-badge&color=11b8cc">
  </a>
</p>

tgpirobot is a Python library that allows you to auto-reply to messages on Telegram when you are offline!

## 🚀 Features

- Send automatic replies when offline ✔️
- Block spammers who send too many messages ❌️  
- Reply with jokes, quotes to engage users 🃏
- Get notifications when someone messages you 📨
- Customize replies easily!

<br>
  
<p align="center">
  <img src="https://raw.githubusercontent.com/hk4crprasad/tgpirobot/master/IMG_20231118_231056.jpg">
</p>

<p align="center"> 
  <b>Demo of tgpirobot auto-replying on Telegram</b>
</p>

## 📥 Installation

```bash
pip install tgpirobot
```

```bash
git clone https://github.com/hk4crprasad/tgpirobot.git
cd tgpirobot
pip install .
```

## 🤹 Usage

### Get API Credentials

<a href="https://my.telegram.org"><img src="https://user-images.githubusercontent.com/5070591/115477866-d465d980-a28a-11eb-80e1-f3f5dcfbbdc3.png" width="240px"></a>

- Visit [my.telegram.org](https://my.telegram.org) and login  
- Go to API Development tools
- Create a new app
- Copy `api_id` and `api_hash`

### Run the Bot

```python
Your API_ID: YOUR_API_ID
Your API_HASH: YOUR_API_HASH
Debug mode (true/false): true or false(false is good)
```

Now your account will auto-reply when offline! 🎉

### Its ask for Number and Otp

```python

Enter Number or bot token :- +919000000999
Is the number(+919000000999) is right(Yn) : y
Enter Received Otp from telegram app : 000000

```

## 🧑 Author 

Made with ❤️ by [hk4crprasad](https://github.com/hk4crprasad)

## 📄 License

[GPL-3.0](https://github.com/hk4crprasad/tgpirobot/blob/master/LICENSE)

Let me know if you would like me to modify or enhance this README further!